// src/index.tsx
import { DndProvider } from "react-dnd";
import { HTML5Backend } from "react-dnd-html5-backend";

// src/components/constants.ts
var KEYS = {
  ENTER: [10, 13],
  TAB: 9,
  BACKSPACE: 8,
  UP_ARROW: 38,
  DOWN_ARROW: 40,
  ESCAPE: 27,
  SPACE: 32,
  COMMA: 188
};
var SEPARATORS = {
  ENTER: "Enter",
  TAB: "Tab",
  COMMA: ",",
  SPACE: " ",
  SEMICOLON: ";"
};
var DEFAULT_PLACEHOLDER = "Press enter to add new tag";
var DEFAULT_LABEL_FIELD = "text";
var DEFAULT_CLASSNAMES = {
  tags: "ReactTags__tags",
  tagInput: "ReactTags__tagInput",
  tagInputField: "ReactTags__tagInputField",
  selected: "ReactTags__selected",
  tag: "ReactTags__tag",
  remove: "ReactTags__remove",
  suggestions: "ReactTags__suggestions",
  activeSuggestion: "ReactTags__activeSuggestion",
  editTagInput: "ReactTags__editTagInput",
  editTagInputField: "ReactTags__editTagInputField",
  clearAll: "ReactTags__clearAll"
};
var INPUT_FIELD_POSITIONS = {
  INLINE: "inline",
  TOP: "top",
  BOTTOM: "bottom"
};
var ERRORS = {
  TAG_LIMIT: "Tag limit reached!"
};

// src/components/ReactTags.tsx
import { useEffect as useEffect2, createRef as createRef2, useRef as useRef2, useState, Fragment } from "react";
import uniq from "lodash/uniq";

// src/components/ClearAllTags.tsx
import { jsx } from "react/jsx-runtime";
var ClearAllTags = (props) => {
  return /* @__PURE__ */ jsx("button", { className: props.classNames.clearAll, onClick: props.onClick, children: "Clear all" });
};
var ClearAllTags_default = ClearAllTags;

// src/components/Suggestions.tsx
import { createRef, memo, useEffect } from "react";
import isEqual from "lodash/isEqual";
import escape from "lodash/escape";
import { jsx as jsx2, jsxs } from "react/jsx-runtime";
var maybeScrollSuggestionIntoView = (suggestionEl, suggestionsContainer) => {
  const containerHeight = suggestionsContainer.offsetHeight;
  const suggestionHeight = suggestionEl.offsetHeight;
  const relativeSuggestionTop = suggestionEl.offsetTop - suggestionsContainer.scrollTop;
  if (relativeSuggestionTop + suggestionHeight >= containerHeight) {
    suggestionsContainer.scrollTop += relativeSuggestionTop - containerHeight + suggestionHeight;
  } else if (relativeSuggestionTop < 0) {
    suggestionsContainer.scrollTop += relativeSuggestionTop;
  }
};
var shouldRenderSuggestions = (query, minQueryLength, isFocused, shouldRenderSuggestionsCb) => {
  if (typeof shouldRenderSuggestionsCb === "function") {
    return shouldRenderSuggestionsCb(query);
  }
  return query.length >= minQueryLength && isFocused;
};
var SuggestionsComp = (props) => {
  const suggestionsContainerRef = createRef();
  const {
    labelField,
    minQueryLength,
    isFocused,
    classNames,
    selectedIndex,
    query
  } = props;
  useEffect(() => {
    if (!suggestionsContainerRef.current) {
      return;
    }
    const activeSuggestion = suggestionsContainerRef.current.querySelector(
      `.${classNames.activeSuggestion}`
    );
    if (activeSuggestion) {
      maybeScrollSuggestionIntoView(
        activeSuggestion,
        suggestionsContainerRef.current
      );
    }
  }, [selectedIndex]);
  const markIt = (tag, query2) => {
    const escapedRegex = query2.trim().replace(/[-\\^$*+?.()|[\]{}]/g, "\\$&");
    const { [labelField]: labelValue } = tag;
    return {
      __html: labelValue.replace(RegExp(escapedRegex, "gi"), (x) => {
        return `<mark>${escape(x)}</mark>`;
      })
    };
  };
  const renderSuggestion = (tag, query2) => {
    if (typeof props.renderSuggestion === "function") {
      return props.renderSuggestion(tag, query2);
    }
    return /* @__PURE__ */ jsx2("span", { dangerouslySetInnerHTML: markIt(tag, query2) });
  };
  const suggestions = props.suggestions.map((tag, index) => {
    return /* @__PURE__ */ jsx2(
      "li",
      {
        onMouseDown: props.handleClick.bind(null, index),
        onTouchStart: props.handleClick.bind(null, index),
        onMouseOver: props.handleHover.bind(null, index),
        className: index === props.selectedIndex ? props.classNames.activeSuggestion : "",
        children: renderSuggestion(tag, props.query)
      },
      index
    );
  });
  if (suggestions.length === 0 || !shouldRenderSuggestions(
    query,
    minQueryLength || 2,
    isFocused,
    props.shouldRenderSuggestions
  )) {
    return null;
  }
  return /* @__PURE__ */ jsx2(
    "div",
    {
      ref: suggestionsContainerRef,
      className: classNames.suggestions,
      "data-testid": "suggestions",
      children: /* @__PURE__ */ jsxs("ul", { children: [
        " ",
        suggestions,
        " "
      ] })
    }
  );
};
var arePropsEqual = (prevProps, nextProps) => {
  const { query, minQueryLength = 2, isFocused, suggestions } = nextProps;
  if (prevProps.isFocused === isFocused && isEqual(prevProps.suggestions, suggestions) && shouldRenderSuggestions(
    query,
    minQueryLength,
    isFocused,
    nextProps.shouldRenderSuggestions
  ) === shouldRenderSuggestions(
    prevProps.query,
    prevProps.minQueryLength ?? 2,
    prevProps.isFocused,
    prevProps.shouldRenderSuggestions
  ) && prevProps.selectedIndex === nextProps.selectedIndex) {
    return true;
  }
  return false;
};
var Suggestions = memo(SuggestionsComp, arePropsEqual);
var Suggestions_default = Suggestions;

// src/components/ReactTags.tsx
import ClassNames2 from "classnames";

// src/components/SingleTag.tsx
import { useRef } from "react";
import { useDrag, useDrop } from "react-dnd";
import ClassNames from "classnames";

// src/components/utils.ts
import escapeRegExp from "lodash/escapeRegExp";
function buildRegExpFromDelimiters(delimiters) {
  const delimiterChars = delimiters.map((delimiter) => {
    const chrCode = delimiter - 48 * Math.floor(delimiter / 48);
    return String.fromCharCode(96 <= delimiter ? chrCode : delimiter);
  }).join("");
  const escapedDelimiterChars = escapeRegExp(delimiterChars);
  return new RegExp(`[${escapedDelimiterChars}]+`);
}
function getKeyCodeFromSeparator(separator) {
  switch (separator) {
    case SEPARATORS.ENTER:
      return [10, 13];
    case SEPARATORS.TAB:
      return 9;
    case SEPARATORS.COMMA:
      return 188;
    case SEPARATORS.SPACE:
      return 32;
    case SEPARATORS.SEMICOLON:
      return 186;
    default:
      return 0;
  }
}
function canDrag(params) {
  const { moveTag, readOnly, allowDragDrop } = params;
  return moveTag !== void 0 && !readOnly && allowDragDrop;
}
function canDrop(params) {
  const { readOnly, allowDragDrop } = params;
  return !readOnly && allowDragDrop;
}

// src/components/RemoveComponent.tsx
import { jsx as jsx3 } from "react/jsx-runtime";
var RemoveComponent = (props) => {
  const { readOnly, removeComponent, onRemove, className, tag, index } = props;
  const onKeydown = (event) => {
    if (KEYS.ENTER.includes(event.keyCode) || event.keyCode === KEYS.SPACE) {
      event.preventDefault();
      event.stopPropagation();
      return;
    }
    if (event.keyCode === KEYS.BACKSPACE) {
      onRemove(event);
    }
  };
  if (readOnly) {
    return /* @__PURE__ */ jsx3("span", {});
  }
  const ariaLabel = `Tag at index ${index} with value ${tag.id} focussed. Press backspace to remove`;
  if (removeComponent) {
    const Component = removeComponent;
    return /* @__PURE__ */ jsx3(
      Component,
      {
        "data-testid": "remove",
        onRemove,
        onKeyDown: onKeydown,
        className,
        "aria-label": ariaLabel,
        tag,
        index
      }
    );
  }
  return /* @__PURE__ */ jsx3(
    "button",
    {
      "data-testid": "remove",
      onClick: onRemove,
      onKeyDown: onKeydown,
      className,
      type: "button",
      "aria-label": ariaLabel,
      children: /* @__PURE__ */ jsx3(
        "svg",
        {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 512 512",
          height: "12",
          width: "12",
          fill: "#fff",
          children: /* @__PURE__ */ jsx3("path", { d: "M376.6 84.5c11.3-13.6 9.5-33.8-4.1-45.1s-33.8-9.5-45.1 4.1L192 206 56.6 43.5C45.3 29.9 25.1 28.1 11.5 39.4S-3.9 70.9 7.4 84.5L150.3 256 7.4 427.5c-11.3 13.6-9.5 33.8 4.1 45.1s33.8 9.5 45.1-4.1L192 306 327.4 468.5c11.3 13.6 31.5 15.4 45.1 4.1s15.4-31.5 4.1-45.1L233.7 256 376.6 84.5z" })
        }
      )
    }
  );
};
var RemoveComponent_default = RemoveComponent;

// src/components/SingleTag.tsx
import { jsx as jsx4, jsxs as jsxs2 } from "react/jsx-runtime";
var ItemTypes = { TAG: "tag" };
var SingleTag = (props) => {
  const tagRef = useRef(null);
  const {
    readOnly = false,
    tag,
    classNames,
    index,
    moveTag,
    allowDragDrop = true,
    labelField = "text"
  } = props;
  const [{ isDragging }, drag] = useDrag(() => ({
    type: ItemTypes.TAG,
    collect: (monitor) => ({
      isDragging: !!monitor.isDragging()
    }),
    item: props,
    canDrag: () => canDrag({ moveTag, readOnly, allowDragDrop })
  }));
  const [, drop] = useDrop(() => ({
    accept: ItemTypes.TAG,
    drop: (item) => {
      const dragIndex = item.index;
      const hoverIndex = index;
      if (dragIndex === hoverIndex) {
        return;
      }
      props?.moveTag?.(dragIndex, hoverIndex);
    },
    canDrop: (item) => canDrop(item)
  }));
  drag(drop(tagRef));
  const label = props.tag[props.labelField];
  const { className = "" } = tag;
  const opacity = isDragging ? 0 : 1;
  return /* @__PURE__ */ jsxs2(
    "span",
    {
      ref: tagRef,
      className: ClassNames("tag-wrapper", classNames.tag, className),
      style: {
        opacity,
        cursor: canDrag({ moveTag, readOnly, allowDragDrop }) ? "move" : "auto"
      },
      "data-testid": "tag",
      onClick: props.onTagClicked,
      onTouchStart: props.onTagClicked,
      children: [
        label,
        /* @__PURE__ */ jsx4(
          RemoveComponent_default,
          {
            tag: props.tag,
            className: classNames.remove,
            removeComponent: props.removeComponent,
            onRemove: props.onDelete,
            readOnly,
            index
          }
        )
      ]
    }
  );
};

// src/components/ReactTags.tsx
import { jsx as jsx5, jsxs as jsxs3 } from "react/jsx-runtime";
var ReactTags = (props) => {
  const {
    autofocus,
    autoFocus,
    readOnly,
    labelField,
    allowDeleteFromEmptyInput,
    allowAdditionFromPaste,
    allowDragDrop,
    minQueryLength,
    shouldRenderSuggestions: shouldRenderSuggestions2,
    removeComponent,
    autocomplete,
    inline,
    maxTags,
    allowUnique,
    editable,
    placeholder,
    delimiters,
    separators,
    tags,
    inputFieldPosition,
    inputProps,
    classNames,
    maxLength,
    inputValue,
    clearAll
  } = props;
  const [suggestions, setSuggestions] = useState(props.suggestions);
  const [query, setQuery] = useState("");
  const [isFocused, setIsFocused] = useState(false);
  const [selectedIndex, setSelectedIndex] = useState(-1);
  const [selectionMode, setSelectionMode] = useState(false);
  const [ariaLiveStatus, setAriaLiveStatus] = useState("");
  const [currentEditIndex, setCurrentEditIndex] = useState(-1);
  const [error, setError] = useState("");
  const reactTagsRef = createRef2();
  const textInput = useRef2(null);
  const tagInput = useRef2(null);
  useEffect2(() => {
    if (delimiters.length) {
      console.warn(
        "[Deprecation] The delimiters prop is deprecated and will be removed in v7.x.x, please use separators instead. If you have any concerns regarding this, please share your thoughts in https://github.com/react-tags/react-tags/issues/960"
      );
    }
  }, []);
  useEffect2(() => {
    if (!inline) {
      console.warn(
        "[Deprecation] The inline attribute is deprecated and will be removed in v7.x.x, please use inputFieldPosition instead."
      );
    }
  }, [inline]);
  useEffect2(() => {
    if (autofocus === false) {
      console.warn(
        "[Deprecated] autofocus prop will be removed in 7.x so please migrate to autoFocus prop."
      );
    }
    if (autofocus && autoFocus && !readOnly) {
      resetAndFocusInput();
    }
  }, [autoFocus, autoFocus, readOnly]);
  useEffect2(() => {
    updateSuggestions();
  }, [query, props.suggestions]);
  const filteredSuggestions = (query2) => {
    let updatedSuggestions = props.suggestions.slice();
    if (allowUnique) {
      const existingTags = tags.map((tag) => tag.id.trim().toLowerCase());
      updatedSuggestions = updatedSuggestions.filter(
        (suggestion) => !existingTags.includes(suggestion.id.toLowerCase())
      );
    }
    if (props.handleFilterSuggestions) {
      return props.handleFilterSuggestions(query2, updatedSuggestions);
    }
    const exactSuggestions = updatedSuggestions.filter(
      (item) => getQueryIndex(query2, item) === 0
    );
    const partialSuggestions = updatedSuggestions.filter(
      (item) => getQueryIndex(query2, item) > 0
    );
    return exactSuggestions.concat(partialSuggestions);
  };
  const getQueryIndex = (query2, item) => {
    return item[labelField].toLowerCase().indexOf(query2.toLowerCase());
  };
  const resetAndFocusInput = () => {
    setQuery("");
    if (!textInput.current) {
      return;
    }
    textInput.current.value = "";
    textInput.current.focus();
  };
  const handleDelete = (index, event) => {
    event.preventDefault();
    event.stopPropagation();
    const currentTags = tags.slice();
    if (currentTags.length === 0) {
      return;
    }
    setError("");
    props?.handleDelete?.(index, event);
    updateAriaLiveStatus(index, currentTags);
  };
  const updateAriaLiveStatus = (index, tags2) => {
    if (!reactTagsRef?.current) {
      return;
    }
    const tagRemoveButtons = reactTagsRef.current.querySelectorAll(".ReactTags__remove");
    let ariaLiveStatus2 = "";
    if (index === 0 && tags2.length > 1) {
      ariaLiveStatus2 = `Tag at index ${index} with value ${tags2[index].id} deleted. Tag at index 0 with value ${tags2[1].id} focussed. Press backspace to remove`;
      tagRemoveButtons[0].focus();
    } else if (index > 0) {
      ariaLiveStatus2 = `Tag at index ${index} with value ${tags2[index].id} deleted. Tag at index ${index - 1} with value ${tags2[index - 1].id} focussed. Press backspace to remove`;
      tagRemoveButtons[index - 1].focus();
    } else {
      ariaLiveStatus2 = `Tag at index ${index} with value ${tags2[index].id} deleted. Input focussed. Press enter to add a new tag`;
      textInput.current?.focus();
    }
    setAriaLiveStatus(ariaLiveStatus2);
  };
  const handleTagClick = (index, tag, event) => {
    if (readOnly) {
      return;
    }
    if (editable) {
      setCurrentEditIndex(index);
      setQuery(tag[labelField]);
      tagInput.current?.focus();
    }
    props.handleTagClick?.(index, event);
  };
  const handleChange = (event) => {
    if (props.handleInputChange) {
      props.handleInputChange(event.target.value, event);
    }
    const query2 = event.target.value.trim();
    setQuery(query2);
  };
  const updateSuggestions = () => {
    const newSuggestions = filteredSuggestions(query);
    setSuggestions(newSuggestions);
    setSelectedIndex(
      selectedIndex >= newSuggestions.length ? newSuggestions.length - 1 : selectedIndex
    );
  };
  const handleFocus = (event) => {
    const value = event.target.value;
    if (props.handleInputFocus) {
      props.handleInputFocus(value, event);
    }
    setIsFocused(true);
  };
  const handleBlur = (event) => {
    const value = event.target.value;
    if (props.handleInputBlur) {
      props.handleInputBlur(value, event);
      if (textInput.current) {
        textInput.current.value = "";
      }
    }
    setIsFocused(false);
    setCurrentEditIndex(-1);
  };
  const handleKeyDown = (event) => {
    if (event.key === "Escape") {
      event.preventDefault();
      event.stopPropagation();
      setSelectedIndex(-1);
      setSelectionMode(false);
      setSuggestions([]);
      setCurrentEditIndex(-1);
    }
    if ((separators.indexOf(event.key) !== -1 || delimiters.indexOf(event.keyCode) !== -1) && !event.shiftKey) {
      if (event.keyCode !== KEYS.TAB || query !== "") {
        event.preventDefault();
      }
      const selectedQuery = selectionMode && selectedIndex !== -1 ? suggestions[selectedIndex] : {
        id: query.trim(),
        [labelField]: query.trim(),
        className: ""
      };
      if (Object.keys(selectedQuery)) {
        addTag(selectedQuery);
      }
    }
    if (event.key === "Backspace" && query === "" && (allowDeleteFromEmptyInput || inputFieldPosition === INPUT_FIELD_POSITIONS.INLINE)) {
      handleDelete(tags.length - 1, event);
    }
    if (event.keyCode === KEYS.UP_ARROW) {
      event.preventDefault();
      setSelectedIndex(
        selectedIndex <= 0 ? suggestions.length - 1 : selectedIndex - 1
      );
      setSelectionMode(true);
    }
    if (event.keyCode === KEYS.DOWN_ARROW) {
      event.preventDefault();
      setSelectionMode(true);
      suggestions.length === 0 ? setSelectedIndex(-1) : setSelectedIndex((selectedIndex + 1) % suggestions.length);
    }
  };
  const tagLimitReached = () => {
    return maxTags && tags.length >= maxTags;
  };
  const handlePaste = (event) => {
    if (!allowAdditionFromPaste) {
      return;
    }
    if (tagLimitReached()) {
      setError(ERRORS.TAG_LIMIT);
      resetAndFocusInput();
      return;
    }
    setError("");
    event.preventDefault();
    const clipboardData = event.clipboardData || window.clipboardData;
    const clipboardText = clipboardData.getData("text");
    const { maxLength: maxLength2 = clipboardText.length } = props;
    const maxTextLength = Math.min(maxLength2, clipboardText.length);
    const pastedText = clipboardData.getData("text").substr(0, maxTextLength);
    let keycodes = delimiters;
    if (separators.length) {
      keycodes = [];
      separators.forEach((separator) => {
        const keycode = getKeyCodeFromSeparator(separator);
        if (Array.isArray(keycode)) {
          keycodes = [...keycodes, ...keycode];
        } else {
          keycodes.push(keycode);
        }
      });
    }
    const delimiterRegExp = buildRegExpFromDelimiters(keycodes);
    const tags2 = pastedText.split(delimiterRegExp).map((tag) => tag.trim());
    uniq(tags2).forEach(
      (tag) => addTag({
        id: tag.trim(),
        [labelField]: tag.trim(),
        className: ""
      })
    );
  };
  const addTag = (tag) => {
    if (!tag.id || !tag[labelField]) {
      return;
    }
    if (currentEditIndex === -1) {
      if (tagLimitReached()) {
        setError(ERRORS.TAG_LIMIT);
        resetAndFocusInput();
        return;
      }
      setError("");
    }
    const existingKeys = tags.map((tag2) => tag2.id.toLowerCase());
    if (allowUnique && existingKeys.indexOf(tag.id.trim().toLowerCase()) >= 0) {
      return;
    }
    if (autocomplete) {
      const possibleMatches = filteredSuggestions(tag[labelField]);
      console.warn(
        "[Deprecation] The autocomplete prop will be removed in 7.x to simplify the integration and make it more intutive. If you have any concerns regarding this, please share your thoughts in https://github.com/react-tags/react-tags/issues/949"
      );
      if (autocomplete === 1 && possibleMatches.length === 1 || autocomplete === true && possibleMatches.length) {
        tag = possibleMatches[0];
      }
    }
    if (currentEditIndex !== -1 && props.onTagUpdate)
      props.onTagUpdate(currentEditIndex, tag);
    else props?.handleAddition?.(tag);
    setQuery("");
    setSelectionMode(false);
    setSelectedIndex(-1);
    setCurrentEditIndex(-1);
    resetAndFocusInput();
  };
  const handleSuggestionClick = (index) => {
    addTag(suggestions[index]);
  };
  const handleClearAll = () => {
    if (props.onClearAll) {
      props.onClearAll();
    }
    setError("");
    resetAndFocusInput();
  };
  const handleSuggestionHover = (index) => {
    setSelectedIndex(index);
    setSelectionMode(true);
  };
  const moveTag = (dragIndex, hoverIndex) => {
    const dragTag = tags[dragIndex];
    props?.handleDrag?.(dragTag, dragIndex, hoverIndex);
  };
  const getTagItems = () => {
    const allClassNames2 = { ...DEFAULT_CLASSNAMES, ...props.classNames };
    return tags.map((tag, index) => {
      return /* @__PURE__ */ jsx5(Fragment, { children: currentEditIndex === index ? /* @__PURE__ */ jsx5("div", { className: allClassNames2.editTagInput, children: /* @__PURE__ */ jsx5(
        "input",
        {
          ref: (input) => {
            tagInput.current = input;
          },
          onFocus: handleFocus,
          value: query,
          onChange: handleChange,
          onKeyDown: handleKeyDown,
          onBlur: handleBlur,
          className: allClassNames2.editTagInputField,
          onPaste: handlePaste,
          "data-testid": "tag-edit"
        }
      ) }) : /* @__PURE__ */ jsx5(
        SingleTag,
        {
          index,
          tag,
          labelField,
          onDelete: (event) => handleDelete(index, event),
          moveTag: allowDragDrop ? moveTag : void 0,
          removeComponent,
          onTagClicked: (event) => handleTagClick(index, tag, event),
          readOnly,
          classNames: allClassNames2,
          allowDragDrop
        }
      ) }, index);
    });
  };
  const tagItems = getTagItems();
  const allClassNames = { ...DEFAULT_CLASSNAMES, ...classNames };
  const { name: inputName, id: inputId } = props;
  const position = !inline ? INPUT_FIELD_POSITIONS.BOTTOM : inputFieldPosition;
  const tagsComponent = !readOnly ? /* @__PURE__ */ jsxs3("div", { className: allClassNames.tagInput, children: [
    /* @__PURE__ */ jsx5(
      "input",
      {
        ...inputProps,
        ref: (input) => {
          textInput.current = input;
        },
        className: allClassNames.tagInputField,
        type: "text",
        placeholder,
        "aria-label": placeholder,
        onFocus: handleFocus,
        onBlur: handleBlur,
        onChange: handleChange,
        onKeyDown: handleKeyDown,
        onPaste: handlePaste,
        name: inputName,
        id: inputId,
        maxLength,
        value: inputValue,
        "data-automation": "input",
        "data-testid": "input"
      }
    ),
    /* @__PURE__ */ jsx5(
      Suggestions_default,
      {
        query: query.trim(),
        suggestions,
        labelField,
        selectedIndex,
        handleClick: handleSuggestionClick,
        handleHover: handleSuggestionHover,
        minQueryLength,
        shouldRenderSuggestions: shouldRenderSuggestions2,
        isFocused,
        classNames: allClassNames,
        renderSuggestion: props.renderSuggestion
      }
    ),
    clearAll && tags.length > 0 && /* @__PURE__ */ jsx5(ClearAllTags_default, { classNames: allClassNames, onClick: handleClearAll }),
    error && /* @__PURE__ */ jsxs3("div", { "data-testid": "error", className: "ReactTags__error", children: [
      /* @__PURE__ */ jsx5(
        "svg",
        {
          xmlns: "http://www.w3.org/2000/svg",
          viewBox: "0 0 512 512",
          height: "24",
          width: "24",
          fill: "#e03131",
          children: /* @__PURE__ */ jsx5("path", { d: "M256 32c14.2 0 27.3 7.5 34.5 19.8l216 368c7.3 12.4 7.3 27.7 .2 40.1S486.3 480 472 480H40c-14.3 0-27.6-7.7-34.7-20.1s-7-27.8 .2-40.1l216-368C228.7 39.5 241.8 32 256 32zm0 128c-13.3 0-24 10.7-24 24V296c0 13.3 10.7 24 24 24s24-10.7 24-24V184c0-13.3-10.7-24-24-24zm32 224a32 32 0 1 0 -64 0 32 32 0 1 0 64 0z" })
        }
      ),
      error
    ] })
  ] }) : null;
  return /* @__PURE__ */ jsxs3(
    "div",
    {
      className: ClassNames2(allClassNames.tags, "react-tags-wrapper"),
      ref: reactTagsRef,
      children: [
        /* @__PURE__ */ jsx5(
          "p",
          {
            role: "alert",
            className: "sr-only",
            style: {
              position: "absolute",
              overflow: "hidden",
              clip: "rect(0 0 0 0)",
              margin: "-1px",
              padding: 0,
              width: "1px",
              height: "1px",
              border: 0
            },
            children: ariaLiveStatus
          }
        ),
        position === INPUT_FIELD_POSITIONS.TOP && tagsComponent,
        /* @__PURE__ */ jsxs3("div", { className: allClassNames.selected, children: [
          tagItems,
          position === INPUT_FIELD_POSITIONS.INLINE && tagsComponent
        ] }),
        position === INPUT_FIELD_POSITIONS.BOTTOM && tagsComponent
      ]
    }
  );
};
var ReactTags_default = ReactTags;

// src/index.tsx
import { jsx as jsx6 } from "react/jsx-runtime";
var ReactTagsWrapper = (props) => {
  const {
    placeholder = DEFAULT_PLACEHOLDER,
    labelField = DEFAULT_LABEL_FIELD,
    suggestions = [],
    // Set delimeters to empty array if separators is provided
    delimiters = props.separators?.length ? [] : [...KEYS.ENTER, KEYS.TAB],
    // Set separators to empty array if delimiters is provided
    separators = props.delimiters?.length ? [] : [SEPARATORS.ENTER, SEPARATORS.TAB],
    autofocus = true,
    autoFocus = true,
    inline = true,
    // TODO= Remove in v7.x.x
    inputFieldPosition = "inline",
    allowDeleteFromEmptyInput = false,
    allowAdditionFromPaste = true,
    autocomplete = false,
    readOnly = false,
    allowUnique = true,
    allowDragDrop = true,
    tags = [],
    inputProps = {},
    editable = false,
    clearAll = false,
    handleDelete,
    handleAddition,
    onTagUpdate,
    handleDrag,
    handleFilterSuggestions,
    handleTagClick,
    handleInputChange,
    handleInputFocus,
    handleInputBlur,
    minQueryLength,
    shouldRenderSuggestions: shouldRenderSuggestions2,
    removeComponent,
    onClearAll,
    classNames,
    name,
    id,
    maxLength,
    inputValue,
    maxTags,
    renderSuggestion
  } = props;
  return /* @__PURE__ */ jsx6(
    ReactTags_default,
    {
      placeholder,
      labelField,
      suggestions,
      delimiters,
      separators,
      autofocus,
      autoFocus,
      inline,
      inputFieldPosition,
      allowDeleteFromEmptyInput,
      allowAdditionFromPaste,
      autocomplete,
      readOnly,
      allowUnique,
      allowDragDrop,
      tags,
      inputProps,
      editable,
      clearAll,
      handleDelete,
      handleAddition,
      onTagUpdate,
      handleDrag,
      handleFilterSuggestions,
      handleTagClick,
      handleInputChange,
      handleInputFocus,
      handleInputBlur,
      minQueryLength,
      shouldRenderSuggestions: shouldRenderSuggestions2,
      removeComponent,
      onClearAll,
      classNames,
      name,
      id,
      maxLength,
      inputValue,
      maxTags,
      renderSuggestion
    }
  );
};
var WithContext = ({ ...props }) => (
  // @ts-ignore
  /* @__PURE__ */ jsx6(DndProvider, { backend: HTML5Backend, children: /* @__PURE__ */ jsx6(ReactTagsWrapper, { ...props }) })
);
export {
  KEYS,
  WithContext,
  ReactTagsWrapper as WithOutContext
};
//# sourceMappingURL=index.js.map
